@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -21,9 +21,7 @@ using namespace Akonadi::Search::PIM;
 class Akonadi::Search::PIM::IndexedItemsPrivate
 {
 public:
-    IndexedItemsPrivate()
-    {
-    }
+    IndexedItemsPrivate() = default;
 
     Q_REQUIRED_RESULT QString dbPath(const QString &dbName) const;
     Q_REQUIRED_RESULT QString emailIndexingPath() const;
