@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -35,7 +35,7 @@ public:
     void matchNote(const QString &note);
 
     void setLimit(int limit);
-    int limit() const;
+    Q_REQUIRED_RESULT int limit() const;
 
     ResultIterator exec() override;
 
