@@ -10,9 +10,9 @@
 
 #include <xapian.h>
 
+#include "core/searchstore.h"
+#include "core/term.h"
 #include "search_xapian_export.h"
-#include "searchstore.h"
-#include "term.h"
 
 #include <QMutex>
 
@@ -34,8 +34,8 @@ public:
     void close(int queryId) override;
     bool next(int queryId) override;
 
-    QByteArray id(int queryId) override;
-    QUrl url(int queryId) override;
+    Q_REQUIRED_RESULT QByteArray id(int queryId) override;
+    Q_REQUIRED_RESULT QUrl url(int queryId) override;
 
     /**
      * Set the path of the xapian database
@@ -107,7 +107,7 @@ private:
     };
 
     QHash<int, Result> m_queryMap;
-    int m_nextId;
+    int m_nextId = 1;
 
     QString m_dbPath;
 
